EXPORTS
	??1CEikPasswordModeCategory@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CEikPasswordModeCategory::~CEikPasswordModeCategory(void)
	?GetPasswordModeL@CEikPasswordModeCategory@@QBEXAAW4TPasswordMode@@@Z @ 2 NONAME ; public: void __thiscall CEikPasswordModeCategory::GetPasswordModeL(enum TPasswordMode &)const 
	?NewLC@CEikPasswordModeCategory@@SAPAV1@AAVRFs@@@Z @ 3 NONAME ; public: static class CEikPasswordModeCategory * __cdecl CEikPasswordModeCategory::NewLC(class RFs &)
	?SetPasswordModeL@CEikPasswordModeCategory@@QAEXW4TPasswordMode@@@Z @ 4 NONAME ; public: void __thiscall CEikPasswordModeCategory::SetPasswordModeL(enum TPasswordMode)
	??1CEikUndertaker@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CEikUndertaker::~CEikUndertaker(void)
	??0CEikAlmControlSupervisor@@QAE@XZ @ 6 NONAME ABSENT ; public: __thiscall CEikAlmControlSupervisor::CEikAlmControlSupervisor(void)
	?CmdAcknowledgeAlarm@CEikAlmControlSupervisor@@QAEXXZ @ 7 NONAME ; public: void __thiscall CEikAlmControlSupervisor::CmdAcknowledgeAlarm(void)
	?CmdPauseAlarmSoundL@CEikAlmControlSupervisor@@QAEXH@Z @ 8 NONAME ; public: void __thiscall CEikAlmControlSupervisor::CmdPauseAlarmSoundL(int)
	?CmdSilenceAlarmSound@CEikAlmControlSupervisor@@QAEXXZ @ 9 NONAME ; public: void __thiscall CEikAlmControlSupervisor::CmdSilenceAlarmSound(void)
	?CmdTaskAwayFromAlarmL@CEikAlmControlSupervisor@@QAEHXZ @ 10 NONAME ; public: int __thiscall CEikAlmControlSupervisor::CmdTaskAwayFromAlarmL(void)
	?ConstructL@CEikAlmControlSupervisor@@QAEXPAVMEikServAlarmFactory@@@Z @ 11 NONAME ABSENT ; public: void __thiscall CEikAlmControlSupervisor::ConstructL(class MEikServAlarmFactory *)
	?DisplayInfoPrint@CEikServNotifyServer@@QAEXABVTDesC16@@@Z @ 12 NONAME ; public: void __thiscall CEikServNotifyServer::DisplayInfoPrint(class TDesC16 const &)
	?DisplayNotifier@CEikServNotifyServer@@QAEXABVTDesC16@@000PAVMEikNotifyAlertCompletionObserver@@@Z @ 13 NONAME ; public: void __thiscall CEikServNotifyServer::DisplayNotifier(class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,class TDesC16 const &,class MEikNotifyAlertCompletionObserver *)
	?HandleSwitchOnEvent@CEikServAlarmAlertServer@@QAEXXZ @ 14 NONAME ; public: void __thiscall CEikServAlarmAlertServer::HandleSwitchOnEvent(void)
	?NewL@CEikUndertaker@@SAPAV1@AAVMEikUndertakerObserver@@@Z @ 15 NONAME ; public: static class CEikUndertaker * __cdecl CEikUndertaker::NewL(class MEikUndertakerObserver &)
	??0CEikServEnv@@QAE@XZ @ 16 NONAME ; public: __thiscall CEikServEnv::CEikServEnv(void)
	??1CEikServEnv@@UAE@XZ @ 17 NONAME ; public: virtual __thiscall CEikServEnv::~CEikServEnv(void)
	??0CEikServNotifyServer@@QAE@H@Z @ 18 NONAME ABSENT ; public: __thiscall CEikServNotifyServer::CEikServNotifyServer(int)
	??1CEikServNotifyServer@@UAE@XZ @ 19 NONAME ; public: virtual __thiscall CEikServNotifyServer::~CEikServNotifyServer(void)
	?UpdateL@MEikSrvNotifierBase@@UAEXABVTDesC8@@HABVRMessagePtr2@@@Z @ 20 NONAME ABSENT ; void MEikSrvNotifierBase::UpdateL(class TDesC8 const &, int, class RMessagePtr2 const &)
	?NewL@CEikServAppUiServer@@SAPAV1@XZ @ 21 NONAME ; public: static class CEikServAppUiServer * __cdecl CEikServAppUiServer::NewL(void)
	?HandleSystemEventL@MEikSrvNotifierBase@@UAEXVTUid@@@Z @ 22 NONAME ABSENT ; public: virtual void __thiscall MEikSrvNotifierBase::HandleSystemEventL(class TUid)
	?NotifierCapabilites@MEikSrvNotifierBase@@UAEHXZ @ 23 NONAME ABSENT ; public: virtual int __thiscall MEikSrvNotifierBase::NotifierCapabilites(void)
	?DestroyEnvironment@CEikServEnv@@UAEXXZ @ 24 NONAME ; public: virtual void __thiscall CEikServEnv::DestroyEnvironment(void)
	??0MEikSrvNotifierBase2@@QAE@XZ @ 25 NONAME ; public: __thiscall MEikSrvNotifierBase2::MEikSrvNotifierBase2(void)
	??1MEikSrvNotifierBase2@@UAE@XZ @ 26 NONAME ; public: virtual __thiscall MEikSrvNotifierBase2::~MEikSrvNotifierBase2(void)
	?HandleSystemEventL@MEikSrvNotifierBase2@@UAEXVTUid@@@Z @ 27 NONAME ; public: virtual void __thiscall MEikSrvNotifierBase2::HandleSystemEventL(class TUid)
	?UpdateL@MEikSrvNotifierBase2@@UAEXABVTDesC8@@HABVRMessagePtr2@@@Z @ 28 NONAME ; void MEikSrvNotifierBase2::UpdateL(class TDesC8 const &, int, class RMessagePtr2 const &)
	?MEikSrvNotifierBase2_Reserved_2@MEikSrvNotifierBase2@@EAEXXZ @ 29 NONAME ; private: virtual void __thiscall MEikSrvNotifierBase2::MEikSrvNotifierBase2_Reserved_2(void)
	?NotifierCapabilites@MEikSrvNotifierBase2@@UAEHXZ @ 30 NONAME ; public: virtual int __thiscall MEikSrvNotifierBase2::NotifierCapabilites(void)
	?CmdTaskAwayFromAlarmL@CEikAlmControlSupervisor@@QAEHH@Z @ 31 NONAME ; public: int __thiscall CEikAlmControlSupervisor::CmdTaskAwayFromAlarmL(int)
	?CloseFepAttributes@CEikServSecureData@@SAXXZ @ 32 NONAME ; void CEikServSecureData::CloseFepAttributes(void)
	?CommitFepAttributesL@CEikServSecureData@@SAXXZ @ 33 NONAME ; void CEikServSecureData::CommitFepAttributesL(void)
	?GetBufferedSystemColorListL@CEikServSecureData@@SAPAVCBufBase@@XZ @ 34 NONAME ; class CBufBase * CEikServSecureData::GetBufferedSystemColorListL(void)
	?GetFepAttributeL@CEikServSecureData@@SAXVTUid@@AAVTDes8@@@Z @ 35 NONAME ; void CEikServSecureData::GetFepAttributeL(class TUid, class TDes8 &)
	?GetInstalledFepNameL@CEikServSecureData@@SAXAAVTDes16@@@Z @ 36 NONAME ; void CEikServSecureData::GetInstalledFepNameL(class TDes16 &)
	?OpenFepAttributesL@CEikServSecureData@@SAXXZ @ 37 NONAME ; void CEikServSecureData::OpenFepAttributesL(void)
	?SetBufferedSystemColorListL@CEikServSecureData@@SAXABVTDesC8@@@Z @ 38 NONAME ; void CEikServSecureData::SetBufferedSystemColorListL(class TDesC8 const &)
	?SetFepAttributeL@CEikServSecureData@@SAXVTUid@@ABVTDesC8@@@Z @ 39 NONAME ; void CEikServSecureData::SetFepAttributeL(class TUid, class TDesC8 const &)
	?SetInstalledFepNameL@CEikServSecureData@@SAXABVTDesC16@@H@Z @ 40 NONAME ; void CEikServSecureData::SetInstalledFepNameL(class TDesC16 const &, int)
	?NewL@CEikServAlarmAlertServer@@SAPAV1@PAVMEikServAlarmFactory@@@Z @ 41 NONAME ; class CEikServAlarmAlertServer * CEikServAlarmAlertServer::NewL(class MEikServAlarmFactory *)
	?NewL@CEikServNotifyServer@@SAPAV1@PAVMEikServNotifyAlert@@@Z @ 42 NONAME ; class CEikServNotifyServer * CEikServNotifyServer::NewL(class MEikServNotifyAlert *)
	?StartL@CEikServNotifyServer@@QAEXXZ @ 43 NONAME ; void CEikServNotifyServer::StartL(void)
	?TaskKeyPressedL@CEikServAlarmAlertServer@@QAEXXZ @ 44 NONAME ; void CEikServAlarmAlertServer::TaskKeyPressedL(void)
	?EikServAppUiSessionFactory@CEikServEnv@@QBEPAVMEikServAppUiSessionFactory@@XZ @ 45 NONAME ; class MEikServAppUiSessionFactory * CEikServEnv::EikServAppUiSessionFactory(void) const
	?SetEikServAppUiSessionFactory@CEikServEnv@@QAEXPAVMEikServAppUiSessionFactory@@@Z @ 46 NONAME ; void CEikServEnv::SetEikServAppUiSessionFactory(class MEikServAppUiSessionFactory *)
	??0CEikServAppUiSession@@QAE@PAVMEikServAppUiSessionHandler@@@Z @ 47 NONAME ; CEikServAppUiSession::CEikServAppUiSession(class MEikServAppUiSessionHandler *)
	??1CEikServAppUiSession@@UAE@XZ @ 48 NONAME ; CEikServAppUiSession::~CEikServAppUiSession(void)
	?ConstructL@CEikServAppUiSession@@UAEXXZ @ 49 NONAME ; void CEikServAppUiSession::ConstructL(void)
	?ServiceL@CEikServAppUiSession@@UAEXABVRMessage2@@@Z @ 50 NONAME ; void CEikServAppUiSession::ServiceL(class RMessage2 const &)
	?SetUiDll@CEikServEnv@@QAEXAAVRLibrary@@@Z @ 51 NONAME ; void CEikServEnv::SetUiDll(class RLibrary &)
	?SessionHandler@CEikServAppUiSession@@IBEPAVMEikServAppUiSessionHandler@@XZ @ 52 NONAME ; class MEikServAppUiSessionHandler * CEikServAppUiSession::SessionHandler(void) const
	?ServiceError@CEikServAppUiSession@@UAEXABVRMessage2@@H@Z @ 53 NONAME ; void CEikServAppUiSession::ServiceError(class RMessage2 const &, int)
	?EnableTaskList@CEikServEnv@@QAEXXZ @ 54 NONAME ; void CEikServEnv::EnableTaskList(void)
	?IsTaskListEnabled@CEikServEnv@@QBEHXZ @ 55 NONAME ; int CEikServEnv::IsTaskListEnabled(void) const
	??0CEikServSecureData@@IAE@XZ @ 56 NONAME ABSENT ; CEikServSecureData::CEikServSecureData(void)
	??0MEikNotifyAlertCompletionObserver@@IAE@XZ @ 57 NONAME ; MEikNotifyAlertCompletionObserver::MEikNotifyAlertCompletionObserver(void)
	??0MEikServAppUiSessionFactory@@IAE@XZ @ 58 NONAME ; MEikServAppUiSessionFactory::MEikServAppUiSessionFactory(void)
	??0MEikServAppUiSessionHandler@@IAE@XZ @ 59 NONAME ; MEikServAppUiSessionHandler::MEikServAppUiSessionHandler(void)
	??0MEikSrvNotifierManager@@IAE@XZ @ 60 NONAME ; MEikSrvNotifierManager::MEikSrvNotifierManager(void)
	?CEikAlmControlSupervisor_Reserved1@CEikAlmControlSupervisor@@MAEXXZ @ 61 NONAME ; void CEikAlmControlSupervisor::CEikAlmControlSupervisor_Reserved1(void)
	?CEikAlmControlSupervisor_Reserved2@CEikAlmControlSupervisor@@MAEXXZ @ 62 NONAME ; void CEikAlmControlSupervisor::CEikAlmControlSupervisor_Reserved2(void)
	?CEikServEnv_Reserved1@CEikServEnv@@EAEXXZ @ 63 NONAME ; void CEikServEnv::CEikServEnv_Reserved1(void)
	?CEikServEnv_Reserved2@CEikServEnv@@EAEXXZ @ 64 NONAME ; void CEikServEnv::CEikServEnv_Reserved2(void)
	?CEikServSecureData_Reserved1@CEikServSecureData@@EAEXXZ @ 65 NONAME ABSENT ; void CEikServSecureData::CEikServSecureData_Reserved1(void)
	?CEikServSecureData_Reserved2@CEikServSecureData@@EAEXXZ @ 66 NONAME ABSENT ; void CEikServSecureData::CEikServSecureData_Reserved2(void)
	?CEikServEnv_Reserved3@CEikServEnv@@EAEXXZ @ 67 NONAME ; void CEikServEnv::CEikServEnv_Reserved1(void)
	?CEikServEnv_Reserved4@CEikServEnv@@EAEXXZ @ 68 NONAME ; void CEikServEnv::CEikServEnv_Reserved1(void)
	?CEikServEnv_Reserved5@CEikServEnv@@EAEXXZ @ 69 NONAME ; void CEikServEnv::CEikServEnv_Reserved1(void)
	?CEikServEnv_Reserved6@CEikServEnv@@EAEXXZ @ 70 NONAME ; void CEikServEnv::CEikServEnv_Reserved1(void)
	?MEikNotifyAlertCompletionObserver_Reserved1@MEikNotifyAlertCompletionObserver@@EAEXXZ @ 71 NONAME ; void MEikNotifyAlertCompletionObserver::MEikNotifyAlertCompletionObserver_Reserved1(void)
	?MEikNotifyAlertCompletionObserver_Reserved2@MEikNotifyAlertCompletionObserver@@EAEXXZ @ 72 NONAME ; void MEikNotifyAlertCompletionObserver::MEikNotifyAlertCompletionObserver_Reserved2(void)
	?MEikServAppUiSessionFactory_Reserved1@MEikServAppUiSessionFactory@@EAEXXZ @ 73 NONAME ; void MEikServAppUiSessionFactory::MEikServAppUiSessionFactory_Reserved1(void)
	?MEikServAppUiSessionFactory_Reserved2@MEikServAppUiSessionFactory@@EAEXXZ @ 74 NONAME ; void MEikServAppUiSessionFactory::MEikServAppUiSessionFactory_Reserved2(void)
	?MEikServAppUiSessionHandler_Reserved1@MEikServAppUiSessionHandler@@EAEXXZ @ 75 NONAME ; void MEikServAppUiSessionHandler::MEikServAppUiSessionHandler_Reserved1(void)
	?MEikServAppUiSessionHandler_Reserved2@MEikServAppUiSessionHandler@@EAEXXZ @ 76 NONAME ; void MEikServAppUiSessionHandler::MEikServAppUiSessionHandler_Reserved2(void)
	?MEikSrvNotifierManager_Reserved1@MEikSrvNotifierManager@@EAEXXZ @ 77 NONAME ; void MEikSrvNotifierManager::MEikSrvNotifierManager_Reserved1(void)
	?MEikSrvNotifierManager_Reserved2@MEikSrvNotifierManager@@EAEXXZ @ 78 NONAME ; void MEikSrvNotifierManager::MEikSrvNotifierManager_Reserved2(void)
	?Reserved_1@CEikServEnv@@EAEXXZ @ 79 NONAME ; void CEikServEnv::Reserved_1(void)
	?Reserved_2@CEikServEnv@@EAEXXZ @ 80 NONAME ; void CEikServEnv::Reserved_2(void)
	??0MEikServAlarm@@IAE@XZ @ 81 NONAME ; MEikServAlarm::MEikServAlarm(void)
	??0MEikServAlarmFactory@@IAE@XZ @ 82 NONAME ; MEikServAlarmFactory::MEikServAlarmFactory(void)
	??0MEikServNotifyAlert@@IAE@XZ @ 83 NONAME ; MEikServNotifyAlert::MEikServNotifyAlert(void)
	?MEikServAlarmFactory_Reserved1@MEikServAlarmFactory@@EAEXXZ @ 84 NONAME ; void MEikServAlarmFactory::MEikServAlarmFactory_Reserved1(void)
	?MEikServAlarmFactory_Reserved2@MEikServAlarmFactory@@EAEXXZ @ 85 NONAME ; void MEikServAlarmFactory::MEikServAlarmFactory_Reserved2(void)
	?MEikServAlarm_Reserved1@MEikServAlarm@@EAEXXZ @ 86 NONAME ; void MEikServAlarm::MEikServAlarm_Reserved1(void)
	?MEikServAlarm_Reserved2@MEikServAlarm@@EAEXXZ @ 87 NONAME ; void MEikServAlarm::MEikServAlarm_Reserved2(void)
	?MEikServNotifyAlert_Reserved1@MEikServNotifyAlert@@EAEXXZ @ 88 NONAME ; void MEikServNotifyAlert::MEikServNotifyAlert_Reserved1(void)
	?MEikServNotifyAlert_Reserved2@MEikServNotifyAlert@@EAEXXZ @ 89 NONAME ; void MEikServNotifyAlert::MEikServNotifyAlert_Reserved2(void)
	?AlarmData@CEikAlmControlSupervisor@@QBEAAVTDesC8@@XZ @ 90 NONAME ; class TDesC8 & CEikAlmControlSupervisor::AlarmData(void) const
	?ClearAllAlarmsL@CEikServAlarmAlertServer@@QAEXXZ @ 91 NONAME ; void CEikServAlarmAlertServer::ClearAllAlarmsL(void)
	?NewL@CEikServAlarmAlertServer@@SAPAV1@PAVMEikServAlarmFactory@@H@Z @ 92 NONAME ; class CEikServAlarmAlertServer * CEikServAlarmAlertServer::NewL(class MEikServAlarmFactory *, int)
	?SetQuietPeriodL@CEikServAlarmAlertServer@@QAEXVTTime@@@Z @ 93 NONAME ; void CEikServAlarmAlertServer::SetQuietPeriodL(class TTime)
	?CmdAcknowledgeAllAlarms@CEikAlmControlSupervisor@@QAEXXZ @ 94 NONAME ; void CEikAlmControlSupervisor::CmdAcknowledgeAllAlarms(void)
	?KEikAlarmDefaultSnoozeInMinutes@@3HB @ 95 NONAME ; int const KEikAlarmDefaultSnoozeInMinutes

